@@ -48,7 +48,7 @@ tf_v2 <- function() {
 
     priority = 5,
 
-    environment = "r-tensorflow",
+    environment = "r-reticulate",
 
     on_load = function() {
 
